==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/carplay/CPTemplateApplicationSceneDelegateAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.carplay;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.mapkit.*;
import org.robovm.apple.coreanimation.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/CPTemplateApplicationSceneDelegateAdapter/*</name>*/ 
    extends /*<extends>*/UISceneDelegateAdapter/*</extends>*/ 
    /*<implements>*/implements CPTemplateApplicationSceneDelegate/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @NotImplemented("templateApplicationScene:didConnectInterfaceController:toWindow:")
    public void didConnectInterfaceController(CPTemplateApplicationScene templateApplicationScene, CPInterfaceController interfaceController, CPWindow window) {}
    /**
     * @since Available in iOS 14.0 and later.
     */
    @NotImplemented("templateApplicationScene:didConnectInterfaceController:")
    public void didConnectInterfaceController(CPTemplateApplicationScene templateApplicationScene, CPInterfaceController interfaceController) {}
    @NotImplemented("templateApplicationScene:didDisconnectInterfaceController:fromWindow:")
    public void didDisconnectInterfaceController(CPTemplateApplicationScene templateApplicationScene, CPInterfaceController interfaceController, CPWindow window) {}
    /**
     * @since Available in iOS 14.0 and later.
     */
    @NotImplemented("templateApplicationScene:didDisconnectInterfaceController:")
    public void didDisconnectInterfaceController(CPTemplateApplicationScene templateApplicationScene, CPInterfaceController interfaceController) {}
    @NotImplemented("templateApplicationScene:didSelectNavigationAlert:")
    public void didSelectNavigationAlert(CPTemplateApplicationScene templateApplicationScene, CPNavigationAlert navigationAlert) {}
    @NotImplemented("templateApplicationScene:didSelectManeuver:")
    public void didSelectManeuver(CPTemplateApplicationScene templateApplicationScene, CPManeuver maneuver) {}
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/carplay/CPTemplateApplicationSceneDelegateAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.carplay;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.mapkit.*;
import org.robovm.apple.coreanimation.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/CPTemplateApplicationSceneDelegateAdapter/*</name>*/ 
    extends /*<extends>*/UISceneDelegateAdapter/*</extends>*/ 
    /*<implements>*/implements CPTemplateApplicationSceneDelegate/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @NotImplemented("templateApplicationScene:didConnectInterfaceController:toWindow:")
    public void didConnectInterfaceController(CPTemplateApplicationScene templateApplicationScene, CPInterfaceController interfaceController, CPWindow window) {}
    /**
     * @since Available in iOS 14.0 and later.
     */
    @NotImplemented("templateApplicationScene:didConnectInterfaceController:")
    public void didConnectInterfaceController(CPTemplateApplicationScene templateApplicationScene, CPInterfaceController interfaceController) {}
    @NotImplemented("templateApplicationScene:didDisconnectInterfaceController:fromWindow:")
    public void didDisconnectInterfaceController(CPTemplateApplicationScene templateApplicationScene, CPInterfaceController interfaceController, CPWindow window) {}
    /**
     * @since Available in iOS 14.0 and later.
     */
    @NotImplemented("templateApplicationScene:didDisconnectInterfaceController:")
    public void didDisconnectInterfaceController(CPTemplateApplicationScene templateApplicationScene, CPInterfaceController interfaceController) {}
    @NotImplemented("templateApplicationScene:didSelectNavigationAlert:")
    public void didSelectNavigationAlert(CPTemplateApplicationScene templateApplicationScene, CPNavigationAlert navigationAlert) {}
    @NotImplemented("templateApplicationScene:didSelectManeuver:")
    public void didSelectManeuver(CPTemplateApplicationScene templateApplicationScene, CPManeuver maneuver) {}
    /**
     * @since Available in iOS 15.4 and later.
     */
    @NotImplemented("contentStyleDidChange:")
    public void contentStyleDidChange(UIUserInterfaceStyle contentStyle) {}
    /*</methods>*/
}
